@@ -1,8 +1,8 @@
 import click
 
-from admin import Admin
-from refresh import Refresh
-from users import Users
+from gevault.admin import Admin
+from gevault.refresh import Refresh
+from gevault.users import Users
 
 @click.group()
 def main():
